==> pw-iso20022-SRU2020-9.1.5-sources.jar: com/prowidesoftware/swift/model/mx/MxCamt01800102.java <==

package com.prowidesoftware.swift.model.mx;

import com.prowidesoftware.swift.model.mx.dic.*;
import com.prowidesoftware.swift.model.mx.AbstractMX;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import com.prowidesoftware.swift.model.MxSwiftMessage;
import com.prowidesoftware.swift.model.mx.AbstractMX;
import com.prowidesoftware.swift.model.mx.MxRead;
import com.prowidesoftware.swift.model.mx.MxReadImpl;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Class for camt.018.001.02 ISO 20022 message.
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "Document", propOrder = {
    "getBizDayInf"
})
@XmlRootElement(name = "Document", namespace = "urn:swift:xsd:camt.018.001.02")
public class MxCamt01800102
    extends AbstractMX
{

    @XmlElement(name = "GetBizDayInf", required = true)
    protected GetBusinessDayInformationV02 getBizDayInf;
    public final static transient String BUSINESS_PROCESS = "camt";
    public final static transient int FUNCTIONALITY = 18;
    public final static transient int VARIANT = 1;
    public final static transient int VERSION = 2;
    @SuppressWarnings("rawtypes")
    public final static transient Class[] _classes = new Class[] {BusinessDayInformationCriteria.class, BusinessDayInformationCriteriaDefinitionChoice.class, BusinessDayInformationQueryDefinition2 .class, BusinessDayInformationReturnCriteria.class, BusinessDayInformationSearchCriteria.class, CashClearingSystem1Code.class, GetBusinessDayInformationV02 .class, MessageIdentification.class, MxCamt01800102 .class, QueryType2Code.class, SystemIdentificationChoice.class };
    public final static transient String NAMESPACE = "urn:swift:xsd:camt.018.001.02";

    public MxCamt01800102() {
        super();
    }

    /**
     * Creates the MX object parsing the parameter String with the XML content
     * 
     */
    public MxCamt01800102(final String xml) {
        this();
        MxCamt01800102 tmp = parse(xml);
        getBizDayInf = tmp.getGetBizDayInf();
    }

    /**
     * Creates the MX object parsing the raw content from the parameter MxSwiftMessage
     * 
     */
    public MxCamt01800102(final MxSwiftMessage mxSwiftMessage) {
        this(mxSwiftMessage.message());
    }

    /**
     * Gets the value of the getBizDayInf property.
     * 
     * @return
     *     possible object is
     *     {@link GetBusinessDayInformationV02 }
     *     
     */
    public GetBusinessDayInformationV02 getGetBizDayInf() {
        return getBizDayInf;
    }

    /**
     * Sets the value of the getBizDayInf property.
     * 
     * @param value
     *     allowed object is
     *     {@link GetBusinessDayInformationV02 }
     *     
     */
    public MxCamt01800102 setGetBizDayInf(GetBusinessDayInformationV02 value) {
        this.getBizDayInf = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

    @Override
    public String getBusinessProcess() {
        return BUSINESS_PROCESS;
    }

    @Override
    public int getFunctionality() {
        return FUNCTIONALITY;
    }

    @Override
    public int getVariant() {
        return VARIANT;
    }

    @Override
    public int getVersion() {
        return VERSION;
    }

    /**
     * Creates the MX object parsing the raw content from the parameter XML
     * 
     */
    public static MxCamt01800102 parse(String xml) {
        return ((MxCamt01800102) MxReadImpl.parse(MxCamt01800102 .class, xml, _classes));
    }

    /**
     * Creates the MX object parsing the raw content from the parameter XML with injected read implementation
     * @since 9.0.1
     * 
     * @param parserImpl an MX unmarshall implementation
     */
    public static MxCamt01800102 parse(String xml, MxRead parserImpl) {
        return ((MxCamt01800102) parserImpl.read(MxCamt01800102 .class, xml, _classes));
    }

    @Override
    public String getNamespace() {
        return NAMESPACE;
    }

    @Override
    @SuppressWarnings("rawtypes")
    public Class[] getClasses() {
        return _classes;
    }

    /**
     * Creates an MxCamt01800102 messages from its JSON representation.
     * <p>
     * For generic conversion of JSON into the corresponding MX instance 
     * see {@link AbstractMX#fromJson(String)}
     * 
     * @since 7.10.2
     * 
     * @param json a JSON representation of an MxCamt01800102 message
     * @return
     *     a new instance of MxCamt01800102
     */
    public final static MxCamt01800102 fromJson(String json) {
        return AbstractMX.fromJson(json, MxCamt01800102 .class);
    }

}

==> pw-iso20022-SRU2023-10.1.4-sources.jar: com/prowidesoftware/swift/model/mx/MxCamt01800102.java <==

package com.prowidesoftware.swift.model.mx;

import com.prowidesoftware.swift.model.mx.dic.*;
import com.prowidesoftware.swift.model.mx.AbstractMX;

import com.prowidesoftware.swift.model.MxSwiftMessage;
import com.prowidesoftware.swift.model.mx.MxRead;
import com.prowidesoftware.swift.model.mx.MxReadConfiguration;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Class for camt.018.001.02 ISO 20022 message.
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "Document", propOrder = {
    "getBizDayInf"
})
@XmlRootElement(name = "Document", namespace = "urn:swift:xsd:camt.018.001.02")
public class MxCamt01800102
    extends com.prowidesoftware.swift.model.mx.AbstractMX
{

    @XmlElement(name = "GetBizDayInf", required = true)
    protected GetBusinessDayInformationV02 getBizDayInf;
    public static final transient String BUSINESS_PROCESS = "camt";
    public static final transient int FUNCTIONALITY = 18;
    public static final transient int VARIANT = 1;
    public static final transient int VERSION = 2;
    @SuppressWarnings("rawtypes")
    public static final transient Class[] _classes = new Class[] {BusinessDayInformationCriteria.class, BusinessDayInformationCriteriaDefinitionChoice.class, BusinessDayInformationQueryDefinition2 .class, BusinessDayInformationReturnCriteria.class, BusinessDayInformationSearchCriteria.class, CashClearingSystem1Code.class, GetBusinessDayInformationV02 .class, MessageIdentification.class, MxCamt01800102 .class, QueryType2Code.class, SystemIdentificationChoice.class };
    public static final transient String NAMESPACE = "urn:swift:xsd:camt.018.001.02";

    public MxCamt01800102() {
        super();
    }

    /**
     * Creates the MX object parsing the parameter String with the XML content
     * 
     */
    public MxCamt01800102(final String xml) {
        this();
        MxCamt01800102 tmp = parse(xml);
        getBizDayInf = tmp.getGetBizDayInf();
    }

    /**
     * Creates the MX object parsing the raw content from the parameter MxSwiftMessage
     * 
     */
    public MxCamt01800102(final MxSwiftMessage mxSwiftMessage) {
        this(mxSwiftMessage.message());
    }

    /**
     * Gets the value of the getBizDayInf property.
     * 
     * @return
     *     possible object is
     *     {@link GetBusinessDayInformationV02 }
     *     
     */
    public GetBusinessDayInformationV02 getGetBizDayInf() {
        return getBizDayInf;
    }

    /**
     * Sets the value of the getBizDayInf property.
     * 
     * @param value
     *     allowed object is
     *     {@link GetBusinessDayInformationV02 }
     *     
     */
    public MxCamt01800102 setGetBizDayInf(GetBusinessDayInformationV02 value) {
        this.getBizDayInf = value;
        return this;
    }

    @Override
    public String getBusinessProcess() {
        return BUSINESS_PROCESS;
    }

    @Override
    public int getFunctionality() {
        return FUNCTIONALITY;
    }

    @Override
    public int getVariant() {
        return VARIANT;
    }

    @Override
    public int getVersion() {
        return VERSION;
    }

    /**
     * Creates the MX object parsing the raw content from the parameter XML, using default unmarshalling options
     * 
     */
    public static MxCamt01800102 parse(String xml) {
        return ((MxCamt01800102) com.prowidesoftware.swift.model.mx.MxReadImpl.parse(MxCamt01800102 .class, xml, _classes, new com.prowidesoftware.swift.model.mx.MxReadParams()));
    }

    /**
     * Creates the MX object parsing the raw content from the parameter XML, using the provided unmarshalling options
     * @since 9.2.6
     * 
     */
    public static MxCamt01800102 parse(String xml, MxReadConfiguration conf) {
        return ((MxCamt01800102) com.prowidesoftware.swift.model.mx.MxReadImpl.parse(MxCamt01800102 .class, xml, _classes, new com.prowidesoftware.swift.model.mx.MxReadParams(conf)));
    }

    /**
     * Creates the MX object parsing the raw content from the parameter XML with injected read implementation
     * @since 9.0.1
     * 
     * @param parserImpl an MX unmarshall implementation
     */
    public static MxCamt01800102 parse(String xml, MxRead parserImpl) {
        return ((MxCamt01800102) parserImpl.read(MxCamt01800102 .class, xml, _classes));
    }

    @Override
    public String getNamespace() {
        return NAMESPACE;
    }

    @Override
    @SuppressWarnings("rawtypes")
    public Class[] getClasses() {
        return _classes;
    }

    /**
     * Creates an MxCamt01800102 messages from its JSON representation.
     * <p>
     * For generic conversion of JSON into the corresponding MX instance 
     * see {@link AbstractMX#fromJson(String)}
     * 
     * @since 7.10.2
     * 
     * @param json a JSON representation of an MxCamt01800102 message
     * @return
     *     a new instance of MxCamt01800102
     */
    public static final MxCamt01800102 fromJson(String json) {
        return com.prowidesoftware.swift.model.mx.AbstractMX.fromJson(json, MxCamt01800102 .class);
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}
